@@ -61,11 +61,11 @@ def pytest_sessionfinish(session, exitstatus):  # noqa: ARG001
             Plugin.SERVER.stop()
 
 
-@pytest.fixture()
+@pytest.fixture
 def httpserver(make_httpserver):
     server = make_httpserver
-    yield server
     server.clear()
+    return server
 
 
 @pytest.fixture(scope="session")
@@ -78,11 +78,11 @@ def make_httpserver_ipv4(httpserver_ssl_context):
         server.stop()
 
 
-@pytest.fixture()
+@pytest.fixture
 def httpserver_ipv4(make_httpserver_ipv4):
     server = make_httpserver_ipv4
-    yield server
     server.clear()
+    return server
 
 
 @pytest.fixture(scope="session")
@@ -95,8 +95,8 @@ def make_httpserver_ipv6(httpserver_ssl_context):
         server.stop()
 
 
-@pytest.fixture()
+@pytest.fixture
 def httpserver_ipv6(make_httpserver_ipv6):
     server = make_httpserver_ipv6
-    yield server
     server.clear()
+    return server
